==> simple-sync-phone-v2024-07-23.1.tar.gz: simple-sync-phone/bin/simple-sync-phone.sh <==
#!/bin/bash -e
#
# simple-sync-phone:bin/simple-sync-phone.sh
#
set -u
set -o pipefail

PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_HOME

# shellcheck disable=SC1091
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit $?
# shellcheck disable=SC1091
source "${PROJECT_HOME}/bin/api/rsync-to-phone-config-api.sh" || exit $?
# shellcheck disable=SC1091
source "${PROJECT_HOME}/bin/api/find-port-on-network-api.sh" || exit $?
# shellcheck disable=SC1091
source "${PROJECT_HOME}/bin/api/rsync-to-phone-api.sh" || exit $?
# shellcheck disable=SC1091
source "${PROJECT_HOME}/bin/api/simplesshd-api.sh" || exit $?

function usage {
  cat <<EOF
Configure and synchronize phone.

Usage:

  $( basename "$0" ) --help
  $( basename "$0" ) --port PORT [--ip IP] [--user USER] --init [--debug]
  $( basename "$0" ) --port PORT [--ip IP] [--user USER] --source SOURCE --destination DEST [--init] [--debug]

Options
  -h,           --help      Display this messsage and exit.
                --debug     Show extra informations
  -D DEST,      --destination DEST
                            Set destination (file or directory) (ie:/sdcard/Pictures)
                            Destination directory must exist on phone
                --init      Add ssh public key on give phone
                --ip IP     Phone IP (ie: 192.168.1.177)
  -P PORT,      --port PORT Port to use (ie: 2222)
  -S SOURCE,    --source SOURCE
                            Set source (file or directory)
  -U USER,      --user USER Change username (default: ${RSYNC_TO_PHONE_REMOTE_USER})

Samples:

  Configure public key by overwriting authorized_keys on Phone
    $( basename "$0" ) -P 2223 --init

  Copy a local file info Documents folder of Phone
    $( basename "$0" ) -P 2223 --source "\${HOME}/Documents/testfile.json" -D '/sdcard/Documents/'

EOF
}

function main {
  local param=
  local param_action_copy=
  local param_action_init=
  local param_destination=
  local param_ip=
  local param_port=
  local param_source=
  local param_remote_user=

  while [ "$#" -gt 0 ] ; do
    param="$1"
    shift

    case "${param}" in
      '-h'|'--help')
        usage
        return 0
        ;;

      '-P'|'--port')
        param_port="$( P_param "$@" )" && shift || return $?
        if ! is_positive_integer "${param_port}" ; then
         echofatal '--port must be a positive number.'
         return 100
        fi
        if [ "${param_port}" -lt 1 ] || [ "${param_port}" -gt 65534 ] ; then
         echofatal '--port must be a number from 1024 to 65534'
         return 100
        fi
        ;;

      '--init')
        param_action_init='true'
        ;;

      '--ip')
        param_ip="$( P_param "$@" )" && shift || return $?
        ;;

      '-S'|'--source')
        param_action_copy='true'
        param_source="$( P_param "$@" )" && shift || return $?
        ;;

      '-D'|'--destination')
        param_action_copy='true'
        param_destination="$( P_param "$@" )" && shift || return $?
        ;;

      '-U'|'--user')
        param_remote_user="$( P_param "$@" )" && shift || return $?
        if [ -n "${param_remote_user}" ] ; then
          declare -gx RSYNC_TO_PHONE_REMOTE_USER="${param_remote_user}"
        fi
        ;;

      '--debug')
        declare -gx MESSAGE_API_SHOW_DEBUG='true'
        declare -gx VERBOSE='true'
        declare -gx __DEBUG_NMAP__='true'
        ;;

      *)
        echofatal "Unknown option: '${param}'"
        usage >&2
        return 1
        ;;
    esac
  done

  if [ "${VERBOSE:-}" = 'true' ] ; then
    echodebug "param_action_copy='${param_action_copy}'"
    echodebug "param_action_init='${param_action_init}'"
    echodebug "param_destination='${param_destination}'"
    echodebug "param_ip='${param_ip}'"
    echodebug "param_port='${param_port}'"
    echodebug "param_remote_user='${param_remote_user}'"
    echodebug "param_source='${param_source}'"
    echodebug "RSYNC_TO_PHONE_REMOTE_USER='${RSYNC_TO_PHONE_REMOTE_USER}'"
  fi

  requirements_tools || return $?
  requirements_config || return $?

  if [ "${param_action_init}" = 'true' ] || [ "${param_action_copy}"  = 'true' ] ;then
    if [ -z "${param_port}" ] ; then
      echofatal 'Parameter --port is missing.'
      return 100
    fi
    if [ -z "${param_ip}" ] ; then
      param_ip="$( find_port_on_ipv4_network "${param_port}" )" || return $?
    fi
    if [ -z "${param_ip}" ] ; then
      echofatal "Parameter --ip is missing and can't find open port '${param_port}' in network."
      return 100
    fi
  fi

  if [ "${param_action_init}" = 'true' ] ; then
    requirements_config_init_pub_key_file || return $?
    init_authorized_keys "${PUB_KEY_FILE}" "${param_ip}" "${param_port}" || return $?
  fi

  if [ "${param_action_copy}"  = 'true' ] ;then
    if [ -z "${param_source}" ] ; then
      echofatal 'Parameter --source is missing.'
      return 100
    fi
    if [ -z "${param_destination}" ] ; then
      echofatal 'Parameter --destination is missing.'
      return 100
    fi
    rsync_to_phone "${param_ip}" "${param_port}"  "${param_source}" "${param_destination}" || return $?
  fi
}

main "$@" || exit $?

==> simple-sync-phone-v2024-07-31.01.tar.gz: simple-sync-phone/bin/simple-sync-phone.sh <==
#!/bin/bash -e
#
# simple-sync-phone:bin/simple-sync-phone.sh
#
set -u
set -o pipefail

# if the script was not launched from a terminal, restart it from a terminal
if [[ ! -t 0 && -x /usr/bin/x-terminal-emulator ]]; then
  /usr/bin/x-terminal-emulator -e "bash -c \"'$0' $*; read -s -p 'Press enter to continue...'\""
  exit
fi

PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_HOME

declare -g WAIT=

# shellcheck disable=SC1091
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit $?
# shellcheck disable=SC1091
source "${PROJECT_HOME}/bin/api/rsync-to-phone-config-api.sh" || exit $?
# shellcheck disable=SC1091
source "${PROJECT_HOME}/bin/api/cli/rsync-to-phone-config-api.sh" || exit $?
# shellcheck disable=SC1091
source "${PROJECT_HOME}/bin/api/find-port-on-network-api.sh" || exit $?
# shellcheck disable=SC1091
source "${PROJECT_HOME}/bin/api/rsync-to-phone-api.sh" || exit $?
# shellcheck disable=SC1091
source "${PROJECT_HOME}/bin/api/cli/rsync-to-phone-ui-api.sh" || exit $?
# shellcheck disable=SC1091
source "${PROJECT_HOME}/bin/api/simplesshd-api.sh" || exit $?

function usage {
  cat <<EOF
Configure and synchronize phone.

Usage:

  $( basename "$0" ) --help
  $( basename "$0" ) --port PORT [--ip IP] [--user USER] --init [--debug] [-skip-checks] [--pause]
  $( basename "$0" ) --port PORT [--ip IP] [--user USER] --source SOURCE --destination DEST [--copy-into] [--debug] [-skip-checks] [--pause]

Options
  -h,           --help      Display this messsage and exit.
                --copy-into When SOURCE is a directory, copy into DESTINATION directory root - Does not create a sub directory.
                --debug     Show extra informations
  -D DEST,      --destination DEST
                            Set destination (file or directory) (ie:/sdcard/Pictures)
                            Destination directory must exist on phone
                --init      Add ssh public key on give phone
                --ip IP     Phone IP (ie: 192.168.1.177)
  -P PORT,      --port PORT Port to use (ie: 2222)
                --skip-checks
                            Skip requirements checks (speed up initialisation)
  -S SOURCE,    --source SOURCE
                            Set source (file or directory). Must be a local existing file (or directory)
  -U USER,      --user USER Change username (default: ${RSYNC_TO_PHONE_REMOTE_USER})
                --pause     Wait for any key before exiting.

Samples:

  Configure public key by overwriting authorized_keys on Phone
    $( basename "$0" ) -P 2223 --init

  Copy a local file info Documents folder of Phone
    $( basename "$0" ) -P 2223 --source "\${HOME}/Documents/testfile.json" -D '/sdcard/Documents/'

  Copy a local directory info already existing directory 'Pictures/simple-sync-phone/Screenshots' on Phone
    $( basename "$0" ) -P 2223 --source "\${HOME}/Pictures/Screenshots" -D '/sdcard/Pictures/simple-sync-phone/Screenshots' --copy-into
  or
    $( basename "$0" ) -P 2223 --source "\${HOME}/Pictures/Screenshots" -D '/sdcard/Pictures/simple-sync-phone/'

EOF
}

function main {
  local param=
  local param_action_copy=
  local param_action_init=
  local param_copy_into='false'
  local param_destination=
  local param_ip=
  local param_port=
  local param_remote_user=
  local param_skip_requirements_check=
  local param_source=

  while [ "$#" -gt 0 ] ; do
    param="$1"
    shift

    case "${param}" in
      '-h'|'--help')
        usage
        return 0
        ;;

      '-P'|'--port')
        param_port="$( P_param "$@" )" && shift || return $?
        if ! is_positive_integer "${param_port}" ; then
         echofatal '--port must be a positive number.'
         return 100
        fi
        if [ "${param_port}" -lt 1 ] || [ "${param_port}" -gt 65534 ] ; then
         echofatal '--port must be a number from 1024 to 65534'
         return 100
        fi
        ;;

      '--init')
        param_action_init='true'
        ;;

      '--ip')
        param_ip="$( P_param "$@" )" && shift || return $?
        ;;

      '-S'|'--source')
        param_action_copy='true'
        param_source="$( P_param "$@" )" && shift || return $?
        ;;

      '-D'|'--destination')
        param_action_copy='true'
        param_destination="$( P_param "$@" )" && shift || return $?
        ;;

      '--skip-checks')
        param_skip_requirements_check='true'
        ;;

      '-U'|'--user')
        param_remote_user="$( P_param "$@" )" && shift || return $?
        if [ -n "${param_remote_user}" ] ; then
          declare -gx RSYNC_TO_PHONE_REMOTE_USER="${param_remote_user}"
        fi
        ;;

      '--copy-into')
        param_copy_into='true'
        ;;

      '--debug')
        declare -gx MESSAGE_API_SHOW_DEBUG='true'
        declare -gx VERBOSE='true'
        declare -gx __DEBUG_NMAP__='true'
        ;;

      '--pause')
        declare -gx WAIT='true'
        ;;

      *)
        echofatal "Unknown option: '${param}'"
        usage >&2
        return 1
        ;;
    esac
  done

  if [ "${VERBOSE:-}" = 'true' ] ; then
    echodebug "RSYNC_TO_PHONE_REMOTE_USER='${RSYNC_TO_PHONE_REMOTE_USER}'"
    echodebug "param_action_copy='${param_action_copy}'"
    echodebug "param_action_init='${param_action_init}'"
    echodebug "param_destination='${param_destination}'"
    echodebug "param_ip='${param_ip}'"
    echodebug "param_port='${param_port}'"
    echodebug "param_remote_user='${param_remote_user}'"
    echodebug "param_skip_requirements_check='${param_skip_requirements_check}'"
    echodebug "param_source='${param_source}'"
  fi

  if [ "${param_skip_requirements_check}" != 'true' ] ; then
    requirements_tools || return $?
    requirements_config || return $?
  fi

  if [ "${param_action_init}" = 'true' ] || [ "${param_action_copy}"  = 'true' ] ;then
    if [ -z "${param_port}" ] ; then
      echofatal 'Parameter --port is missing.'
      return 100
    fi
    if [ -z "${param_ip}" ] ; then
      param_ip="$( find_port_on_ipv4_network "${param_port}" )" || return $?
    fi
    if [ -z "${param_ip}" ] ; then
      echofatal "Parameter --ip is missing and can't find open port '${param_port}' in network."
      return 100
    fi
  fi

  if [ "${param_action_init}" = 'true' ] ; then
    requirements_config_init_pub_key_file || return $?
    init_authorized_keys "${PUB_KEY_FILE}" "${param_ip}" "${param_port}" || return $?
  fi

  if [ "${param_action_copy}"  = 'true' ] ;then
    if [ -z "${param_source}" ] ; then
      echofatal 'Parameter --source is missing.'
      return 100
    fi
    if [ -z "${param_destination}" ] ; then
      echofatal 'Parameter --destination is missing.'
      return 100
    fi
    rsync_to_phone_ui "${param_ip}" "${param_port}" "${param_copy_into}" "${param_source}" "${param_destination}" || return $?
  fi
}

function main_exit_wraper {
  local -i return_code=0

  main "$@" || return_code=$?

  if [ "${WAIT}" = 'true' ] ; then
    echo "Return code: ${return_code}"
    read -n 1 -s -r -p 'Press any key to continue...'
  fi
}

main_exit_wraper "$@" || exit $?
